==> eslint-config-netlify-1.0.0.tgz: package/index.js <==
module.exports = {
  parser: 'babel-eslint',
  env: {
    es6: true,
    browser: true,
    node: true,
    commonjs: true,
    mocha: true,
    jest: true,
  },
  extends: [
    'eslint-config-airbnb',
  ],
  plugins: [
    'class-property',
  ],
  settings: {
    'import/resolver': 'webpack',
  },
  globals: {
    netlify: true,
  },
  rules: {
    // Overrides from the AirBnb configs
    'no-console': 'error',
    'no-shadow': ['warn', {
      builtinGlobals: true,
      allow: ['resolve', 'reject', 'done', 'cb'],
    }],
    'template-curly-spacing': ['error', 'always'],
    'jsx-quotes': ['error', 'prefer-double'],
    'max-len': ['error', 160, 2, {
      ignoreUrls: true,
      ignoreComments: false,
      ignoreStrings: true,
      ignoreTemplateLiterals: true,
    }],
    'new-cap': [2, {
      newIsCap: true,
      capIsNewExceptions: ['Immutable', 'List', 'Map', 'Set', 'OrderedMap'],
    }],

    // React
    'react/jsx-handler-names': ['error', {
      eventHandlerPrefix: 'handle',
      eventHandlerPropPrefix: 'on',
    }],
    'react/jsx-key': 'error',
    'react/jsx-max-props-per-line': ['error', { maximum: 2 }],
    'react/no-direct-mutation-state': 'error',
    'react/jsx-filename-extension': ['off', { extensions: ['.jsx'] }],

    // Class properties
    'class-property/class-property-semicolon': 2,

    // Import
    'import/no-extraneous-dependencies': ['error', {
      devDependencies: [
        '**/webpack*.js',
        '**/*.spec.js',
      ],
    }],
  },
};

==> eslint-config-netlify-1.1.0.tgz: package/index.js <==
module.exports = {
  parser: 'babel-eslint',
  env: {
    es6: true,
    browser: true,
    node: true,
    commonjs: true,
    mocha: true,
    jest: true,
  },
  extends: [
    'eslint-config-airbnb',
  ],
  plugins: [
    'class-property',
  ],
  settings: {
    'import/resolver': 'webpack',
  },
  globals: {
    netlify: true,
  },
  rules: {
    // Overrides from the AirBnb configs
    'no-console': 2,
    'no-shadow': [1, {
      builtinGlobals: true,
      allow: ['resolve', 'reject', 'done', 'cb'],
    }],
    'template-curly-spacing': [2, 'always'],
    'jsx-quotes': [2, 'prefer-double'],
    'max-len': [2, {
      code: 100,
      comments: 100,
      tabWidth: 2,
      ignoreUrls: true,
      ignoreComments: true,
      ignoreTrailingComments: true,
      ignoreStrings: true,
      ignoreTemplateLiterals: true,
    }],
    'new-cap': [2, {
      newIsCap: true,
      capIsNewExceptions: ['Immutable', 'List', 'Map', 'Set', 'OrderedMap'],
    }],

    // React
    'react/jsx-handler-names': [2, {
      eventHandlerPrefix: 'handle',
      eventHandlerPropPrefix: 'on',
    }],
    'react/jsx-key': 2,
    'react/jsx-max-props-per-line': [2, { maximum: 2 }],
    'react/no-direct-mutation-state': 2,
    'react/jsx-filename-extension': 0,

    // Class properties
    'class-property/class-property-semicolon': 2,

    // Import
    'import/no-extraneous-dependencies': [2, {
      devDependencies: [
        '**/webpack*.js',
        '**/*.spec.js',
        '**/*.stories.js',
      ],
    }],
  },
};
